#ifndef _ELM_VIEW_FORM_EO_LEGACY_H_
#define _ELM_VIEW_FORM_EO_LEGACY_H_

#ifndef _ELM_VIEW_FORM_EO_CLASS_TYPE
#define _ELM_VIEW_FORM_EO_CLASS_TYPE

typedef Eo Elm_View_Form;

#endif

#ifndef _ELM_VIEW_FORM_EO_TYPES
#define _ELM_VIEW_FORM_EO_TYPES


#endif



#endif
